@@ -145,7 +145,8 @@ def plot_distr(data_list, column=None, bins=50, labels=None, colors=None, **kwds
 
     column: str or list of them
         Contains the name of the features you want to plot
-        Example: ['dEdx', 'pT', 'ct']
+        Example: ['dEdx', 'pT', 'ct']. If None all the features
+        are selected
 
     bins: int or sequence of scalars or str
         If bins is an int, it defines the number of equal-width
@@ -184,8 +185,9 @@ def plot_distr(data_list, column=None, bins=50, labels=None, colors=None, **kwds
     if column is not None:
         if not isinstance(column, (list, np.ndarray, pd.Index)):
             column = [column]
-        for dfm in list_of_df:
-            dfm = dfm[column]
+
+    else:
+        column = list(list_of_df[0].columns)
 
     if labels is None:
         labels = [f'class{i_class}' for i_class, _ in enumerate(list_of_df)]
@@ -287,7 +289,7 @@ def plot_corr(data_list, columns, labels=None, **kwds):
             tick.tick2line.set_markersize(0)
             tick.label1.set_horizontalalignment('center')
 
-        axs.cax.colorbar(heatmap)
+        plt.colorbar(heatmap, axs.cax)
 
     return res
 
@@ -544,7 +546,7 @@ def plot_roc_train_test(y_truth_test, y_score_test, y_truth_train, y_score_train
 
 def plot_feature_imp(df_in, y_truth, model, labels=None, n_sample=10000, approximate=True):
     """
-    Calculate the feature importance using the shap violin plot for
+    Calculate the feature importance using the shap algorithm for
     each feature. The calculation is performed on a subsample of the
     input training/test set
 
@@ -565,9 +567,8 @@ def plot_feature_imp(df_in, y_truth, model, labels=None, n_sample=10000, approxi
 
     n_sample: int
         Number of candidates employed to fill
-        the shap violin plots.
-        If larger than the number of candidates
-        in each class, minimum number of candidates
+        the shap plots. If larger than the number of
+        candidates in each class, minimum number of candidates
         in a given class used instead
 
     approximate: bool
@@ -576,8 +577,13 @@ def plot_feature_imp(df_in, y_truth, model, labels=None, n_sample=10000, approxi
 
     Returns
     -------------------------------------------
-    out: matplotlib.figure.Figure or list of them
-        Plots with shap feature importance
+    out: List of matplotlib.figure.Figure
+        Plots with shap feature importance. The first ones are the shap violin plots
+        computed for each class(in case of binary classification only one plot is returned).
+        The last plot of the list is built by taking the mean absolute value of the SHAP
+        values for each feature to get a standard bar plot (stacked bars are produced for
+        multi-class outputs)
+
     """
     class_labels, class_counts = np.unique(y_truth, return_counts=True)
     n_classes = len(class_labels)
@@ -590,22 +596,24 @@ def plot_feature_imp(df_in, y_truth, model, labels=None, n_sample=10000, approxi
         subs.append(df_in[y_truth == class_lab].sample(n_sample))
 
     df_subs = pd.concat(subs)
+    df_subs = df_subs[model.get_training_columns()]
     explainer = shap.TreeExplainer(model.get_original_model())
     shap_values = explainer.shap_values(df_subs, approximate=approximate)
+    res = []
 
     if n_classes <= 2:
-        res = plt.figure(figsize=(18, 9))
+        res.append(plt.figure(figsize=(18, 9)))
         shap.summary_plot(shap_values, df_subs, plot_size=(
             18, 9), class_names=labels, show=False)
     else:
-        res = []
         for i_class in range(n_classes):
             res.append(plt.figure(figsize=(18, 9)))
             shap.summary_plot(shap_values[i_class], df_subs, plot_size=(
                 18, 9), class_names=labels, show=False)
-        res.append(plt.figure(figsize=(18, 9)))
-        shap.summary_plot(shap_values, df_subs, plot_type='bar',
-                          plot_size=(18, 9), class_names=labels, show=False)
+
+    res.append(plt.figure(figsize=(18, 9)))
+    shap.summary_plot(shap_values, df_subs, plot_type='bar', plot_size=(
+        18, 9), class_names=labels, show=False)
 
     return res
 
